@@ -1,5 +1,5 @@
 package Net::DNS;
-# $Id: DNS.pm,v 1.55 2003/05/10 12:39:54 ctriv Exp $
+# $Id: DNS.pm,v 1.57 2003/05/22 21:31:49 ctriv Exp $
 
 use strict;
 use vars qw(
@@ -18,7 +18,7 @@ use vars qw(
 );
 
 
-$VERSION = "0.34_02";
+$VERSION = "0.34_03";
 
 use Net::DNS::Resolver;
 use Net::DNS::Packet;
@@ -29,7 +29,7 @@ use Net::DNS::RR;
 
 use XSLoader;
 
-XSLoader::load __PACKAGE__;
+eval { XSLoader::load __PACKAGE__ };
 
 BEGIN {
 	eval { require Net::DNS::RR::SIG };
